This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[gold patch] Add .debug_addr to list of sections used by GDB


This patch adds .debug_addr (a Fission extension) to the list of debug
sections to be kept by the --strip-debug-gdb option. I've also updated
the GDB version number that we're using as a reference, and added
.debug_pubtypes to the list of commented-out sections (i.e., those
that are not used by GDB).

OK to commit?

-cary


2012-05-07  Cary Coutant  <ccoutant@google.com>

	* layout.cc (gdb_sections): Update GDB version, add .debug_addr.
	(lines_only_debug_sections): Likewise.



diff --git a/gold/layout.cc b/gold/layout.cc
index 7155f22..b58f9d2 100644
--- a/gold/layout.cc
+++ b/gold/layout.cc
@@ -455,32 +455,36 @@ Layout::Hash_key::operator()(const Layout::Key& k) const

 // Returns whether the given section is in the list of
 // debug-sections-used-by-some-version-of-gdb.  Currently,
-// we've checked versions of gdb up to and including 6.7.1.
+// we've checked versions of gdb up to and including 7.4.

 static const char* gdb_sections[] =
 { ".debug_abbrev",
-  // ".debug_aranges",   // not used by gdb as of 6.7.1
+  ".debug_addr",         // Fission extension
+  // ".debug_aranges",   // not used by gdb as of 7.4
   ".debug_frame",
   ".debug_info",
   ".debug_types",
   ".debug_line",
   ".debug_loc",
   ".debug_macinfo",
-  // ".debug_pubnames",  // not used by gdb as of 6.7.1
+  // ".debug_pubnames",  // not used by gdb as of 7.4
+  // ".debug_pubtypes",  // not used by gdb as of 7.4
   ".debug_ranges",
   ".debug_str",
 };

 static const char* lines_only_debug_sections[] =
 { ".debug_abbrev",
   // ".debug_aranges",   // not used by gdb as of 6.7.1
   // ".debug_frame",
   ".debug_info",
   // ".debug_types",
   ".debug_line",
   // ".debug_loc",
   // ".debug_macinfo",
-  // ".debug_pubnames",  // not used by gdb as of 6.7.1
+  // ".debug_pubnames",  // not used by gdb as of 7.4
+  // ".debug_pubtypes",  // not used by gdb as of 7.4
   // ".debug_ranges",
   ".debug_str",
 };
@@ -455,32 +455,36 @@ Layout::Hash_key::operator()(const Layout::Key& k) const
 static const char* lines_only_debug_sections[] =
 { ".debug_abbrev",
-  // ".debug_aranges",   // not used by gdb as of 6.7.1
+  // ".debug_addr",      // Fission extension
+  // ".debug_aranges",   // not used by gdb as of 7.4
   // ".debug_frame",
   ".debug_info",


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]